==> Data-Object-0.91.tar.gz: Data-Object-0.91/lib/Data/Object/Func/Hash/Map.pm <==
package Data::Object::Func::Hash::Map;

use Data::Object Class;

extends 'Data::Object::Func::Hash';

# BUILD

has arg1 => (
  is => 'ro',
  isa => 'Object',
  req => 1
);

has arg2 => (
  is => 'ro',
  isa => 'Str | CodeRef',
  req => 1
);

has args => (
  is => 'ro',
  isa => 'ArrayRef[Any]',
  opt => 1
);

# METHODS

sub execute {
  my ($self) = @_;

  my ($data, $code, @args) = $self->unpack;

  my @caught;

  for my $key (keys %$data) {
    my $value = $data->{$key};
    my $refs = {'$key' => \$key, '$value' => \$value};
    push @caught, ($self->codify($code, $refs)->($key, @args));
  }

  return [@caught];
}

sub mapping {
  return ('arg1', 'arg2', '@args');
}

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Hash::Map

=cut

=head1 ABSTRACT

Data-Object Hash Function (Map) Class

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Hash::Map;

  my $func = Data::Object::Func::Hash::Map->new(@args);

  $func->execute;

=cut

=head1 DESCRIPTION

Data::Object::Func::Hash::Map is a function object for Data::Object::Hash.

=cut

=head1 METHODS

This package implements the following methods.

=cut

=head2 execute

  execute() : Object

Executes the function logic and returns the result.

=over 4

=item execute example

  my $data = Data::Object::Hash->new({1..8,9,undef});

  my $func = Data::Object::Func::Hash::Map->new(
    arg1 => $data,
    arg2 => sub { $_[0] + 1 }
  );

  my $result = $func->execute;

=back

=cut

=head2 mapping

  mapping() : (Str)

Returns the ordered list of named function object arguments.

=over 4

=item mapping example

  my @data = $self->mapping;

=back

=cut

==> Data-Object-0.92.tar.gz: Data-Object-0.92/lib/Data/Object/Func/Hash/Map.pm <==
package Data::Object::Func::Hash::Map;

use Data::Object Class;

extends 'Data::Object::Func::Hash';

# BUILD

has arg1 => (
  is => 'ro',
  isa => 'Object',
  req => 1
);

has arg2 => (
  is => 'ro',
  isa => 'CodeRef',
  req => 1
);

has args => (
  is => 'ro',
  isa => 'ArrayRef[Any]',
  opt => 1
);

# METHODS

sub execute {
  my ($self) = @_;

  my ($data, $code, @args) = $self->unpack;

  my @caught;

  for my $key (keys %$data) {
    my $value = $data->{$key};
    push @caught, ($code->($key, @args));
  }

  return [@caught];
}

sub mapping {
  return ('arg1', 'arg2', '@args');
}

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Hash::Map

=cut

=head1 ABSTRACT

Data-Object Hash Function (Map) Class

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Hash::Map;

  my $func = Data::Object::Func::Hash::Map->new(@args);

  $func->execute;

=cut

=head1 DESCRIPTION

Data::Object::Func::Hash::Map is a function object for Data::Object::Hash.

=cut

=head1 METHODS

This package implements the following methods.

=cut

=head2 execute

  execute() : Object

Executes the function logic and returns the result.

=over 4

=item execute example

  my $data = Data::Object::Hash->new({1..8,9,undef});

  my $func = Data::Object::Func::Hash::Map->new(
    arg1 => $data,
    arg2 => sub { $_[0] + 1 }
  );

  my $result = $func->execute;

=back

=cut

=head2 mapping

  mapping() : (Str)

Returns the ordered list of named function object arguments.

=over 4

=item mapping example

  my @data = $self->mapping;

=back

=cut
